@@ -34,9 +34,9 @@ class Constants:
 	FILE_MAX = 512*1024											  # max size of file in FILES_DIR
 	INCOMING_MAX = 64*1024										  # max size allowed in incoming data
 	PLATES = 1													  # 0 if only one site.html, else 1 (0 is faster)
-	LOGGING = 0													  # on is 1, off is 0
+	LOGGING = 1													  # on is 1, off is 0
 	DEMO = 1													  # 1 makes log public
-	LOG_PASSWD = "your_passwd_here"								  # Log passwd, used to reset log
+	LOG_PASSWD = "truck"										  # Log passwd, used to reset log
 	PRIVATE = "private"											  # dir trees hidden from log
 	# E-ZINE CONSTANTS
 	TITHE = 1				  # 1 activates tithing system
@@ -48,15 +48,15 @@ class Constants:
 
 	if (IS_WIN32):
 		DATA = "..\\data"					 # root of all your data files - can be read-only
-		FILES_DIR = "..\\data\\files"		 # incoming data handler's dir - must be read-write
+		FILES_DIR = "..\\files"		 		 # incoming data handler's dir - must be read-write
 		LOG_DIR = FILES_DIR					 # where your log will be written - "." for cgi-bin
 	else:
 		if os.path.exists(os.path.expanduser("~/.my_machine")):
 			DATA = "../data"					 # root of all your data files - can be read-only
-			FILES_DIR = "../data/files"			 # incoming data handler's dir - must be read-write-execute
-		else:	
-			DATA =  os.path.expanduser("~/data") # root of all your data files - can be read-only
-			FILES_DIR = os.path.expanduser("~/data/files") # incoming data handler's dir - must be read-write-execute
+			FILES_DIR = "../files"			 # incoming data handler's dir - must be read-write-execute
+		else:
+			DATA =	os.path.expanduser("~/data") # root of all your data files - can be read-only
+			FILES_DIR = os.path.expanduser("~/files") # incoming data handler's dir - must be read-write-execute
 		LOG_DIR = FILES_DIR					 # where your log will be written - "." for cgi-bin
 
 	# DERIVED CONSTANTS
@@ -68,3 +68,6 @@ class Constants:
 	ID = "<h4>The Ming Server</h4>"
 	E403 = "<h4>Error 403: Forbidden</h4>"
 	E404 = "<h4>Error 404: Resource Not Found</h4>"
+
+#-------------------------------------------------------------------------
+consts = Constants()
