@@ -20,6 +20,7 @@
 # with this program; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
+from TheMingServer import lib
 
 class HTMLParser:
 	NAME = "HTMLParser"
@@ -27,15 +28,13 @@ class HTMLParser:
 	TITLE = "title"
 	DESC = "desc"
 
-	def __init__(self, lib, debug):
-		self.lib = lib
-		self.debug = debug
-		return
+	def __init__(self):
+		pass
 
 	def parse(self, title, desc, data):
 		parsed_data = {
 			self.TITLE:title,
 			self.DESC:desc,
 			}
-		parsed_data = self.lib.parse_data(data, parsed_data)
+		parsed_data = lib.parse_data(data, parsed_data)
 		return parsed_data	
