@@ -24,12 +24,10 @@
 class WebWriter:
 	NAME = "WebWriter"
 
-	def __init__(self, debug):
-		self.debug = debug
-		return
+	def __init__(self):
+		pass
 
 	def write(self, page):
 		print "Content-Type: text/html\n\n"
 		for line in page:
 			print line
-		return 
